@@ -302,6 +302,7 @@ class Runtime:
         retry: bool = False,
         install_local: bool = False,
         offline: bool = False,
+        role_name_check: int = 0,
     ) -> None:
         """Make dependencies available if needed."""
         if required_collections is None:
@@ -342,7 +343,9 @@ class Runtime:
             self.install_collection_from_disk("../..", destination=destination)
         else:
             # no collection, try to recognize and install a standalone role
-            self._install_galaxy_role(self.project_dir, ignore_errors=True)
+            self._install_galaxy_role(
+                self.project_dir, role_name_check=role_name_check, ignore_errors=True
+            )
 
     def require_collection(  # noqa: C901
         self,
@@ -447,6 +450,20 @@ class Runtime:
         if roles_path != self.config.default_roles_path:
             self._update_env("ANSIBLE_ROLES_PATH", roles_path)
 
+    def _get_roles_path(self) -> pathlib.Path:
+        """Return roles installation path.
+
+        If `self.isolated` is set to `True`, `self.cache_dir` would be
+        created, then it returns the `self.cache_dir/roles`. When `self.isolated` is
+        not mentioned or set to `False`, it returns the first path in
+        `default_roles_path`.
+        """
+        if self.cache_dir:
+            path = pathlib.Path(f"{self.cache_dir}/roles")
+        else:
+            path = pathlib.Path(os.path.expanduser(self.config.default_roles_path[0]))
+        return path
+
     def _install_galaxy_role(
         self, project_dir: str, role_name_check: int = 0, ignore_errors: bool = False
     ) -> None:
@@ -495,16 +512,19 @@ class Runtime:
                 fqrn = f"{role_namespace}{role_name}"
             else:
                 fqrn = pathlib.Path(project_dir).absolute().name
-        path = pathlib.Path(os.path.expanduser(self.config.default_roles_path[0]))
+        path = self._get_roles_path()
         path.mkdir(parents=True, exist_ok=True)
         link_path = path / fqrn
         # despite documentation stating that is_file() reports true for symlinks,
         # it appears that is_dir() reports true instead, so we rely on exists().
         target = pathlib.Path(project_dir).absolute()
-        exists = link_path.exists() or link_path.is_symlink()
-        if not exists or os.readlink(link_path) != str(target):
-            if link_path.exists():
-                link_path.unlink()
+        if not link_path.exists() or (
+            link_path.is_symlink() and os.readlink(link_path) != str(target)
+        ):
+            # must call unlink before checking exists because a broken
+            # link reports as not existing and we want to repair it
+            link_path.unlink(missing_ok=True)
+            # https://github.com/python/cpython/issues/73843
             link_path.symlink_to(str(target), target_is_directory=True)
         _logger.info(
             "Using %s symlink to current repository in order to enable Ansible to find the role using its expected full name.",
